@@ -46,8 +46,13 @@ sub create {
 
 sub _other_object {
   my($class, $field, $other) = @_;
+  my $sub_name = $field;
 
-  return $field => sub {
+  # /foo/1/bar => foo_1_bar
+  $sub_name =~ s!/!_!;
+  $sub_name =~ s!^_+!!;
+
+  return $sub_name => sub {
     my $cb = ref $_[-1] eq 'CODE' ? pop : undef;
     my $self = shift;
     my $obj = shift;
@@ -60,18 +65,19 @@ sub _other_object {
       $obj->save(sub {
         my($obj, $err, $doc) = @_;
         $self->$cb($err, $obj) if $err;
+        $self->set($field => $obj->id);
         $self->{_raw}{$field} = $obj->id; # TODO: Should this also be saved to database?
-        $self->{$field} = $obj;
+        $self->{$sub_name} = $obj;
         $self->$cb($err, $obj);
       });
     }
     else { # get =============================================================
       my $collection = $self->connection->_collection($other->description->collection);
-      $collection->find_one({ _id => $self->{_raw}{$field} }, sub {
+      $collection->find_one({ _id => $self->get($field) }, sub {
         my($collection, $err, $doc);
         $self->$cb($err, $obj) if $err;
         $obj = $class->_load_class($other)->new(%$doc, model => $self->model, connection => $self->connection);
-        $self->{$field} = $obj;
+        $self->{$sub_name} = $obj;
         $self->$cb($err, $obj);
       });
     }
